# Generated by Django 5.2.6 on 2025-09-15 09:08

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_orghierarchy", "0012_alter_organization_unique_together_and_more"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AddIndex(
            model_name="organization",
            index=models.Index(fields=["tree_id", "lft"], name="tree_id_lft_idx"),
        ),
        migrations.AddIndex(
            model_name="organization",
            index=models.Index(fields=["id", "tree_id"], name="id_tree_id_idx"),
        ),
        migrations.AddIndex(
            model_name="organization",
            index=models.Index(fields=["lft"], name="lft_idx"),
        ),
        migrations.AddIndex(
            model_name="organization",
            index=models.Index(fields=["tree_id", "id"], name="tree_id_id_idx"),
        ),
        migrations.AddIndex(
            model_name="organization",
            index=models.Index(
                fields=["id", "replaced_by_id"], name="id_replaced_by_id_idx"
            ),
        ),
    ]
